Learn R Programming

aire.zmvm (version 0.9.0)

.get_archive_wsp: Hack to download 2016 WSP HORARIO data since the csv files were converted from mph to m/s (when the original data were already in m/s)

Description

Hack to download 2016 WSP HORARIO data since the csv files were converted from mph to m/s (when the original data were already in m/s)

Usage

.get_archive_wsp(syear)

Value

data.frame

Arguments

syear

shortyear in YY format