Learn R Programming

aire.zmvm (version 0.9.0)

aire.zmvm-package: aire.zmvm package

Description

Tools for downloading data from each of the pollution, wind and temperature measuring stations in the Zona Metropolitana del Valle de México (greater Mexico City).

Arguments

Author

Maintainer: Diego Valle-Jones diego@diegovalle.net

Details

See the README on GitHub

See Also