Learn R Programming

aire.zmvm (version 0.9.0)

deprecated: Deprecated functions in package aire.zmvm.

Description

The functions listed below are deprecated and will be defunct in the near future. When possible, alternative functions with similar functionality are also mentioned.

Usage

get_zone_data(...)
get_latest_data(...)
get_station_single_month(...)

get_latest_data(...)

get_zone_data(...)

get_station_single_month(...)

Value

A data.frame

A data.frame

A data.frame

A data.frame

Arguments

...

Parameters to be passed to the modern version of the function

Details

get_zone_datanow a synonym for get_zone_imeca
get_latest_datanow a synonym for get_latest_imeca
get_station_single_monthnow a synonym for get_station_month_data(criterion = "HORARIOS", ...)