dot-get_archive_wsp: Hack to download 2016 WSP HORARIO data since the csv files...

.get_archive_wspR Documentation

Hack to download 2016 WSP HORARIO data since the csv files were converted from mph to m/s (when the original data were already in m/s)

Description

Hack to download 2016 WSP HORARIO data since the csv files were converted from mph to m/s (when the original data were already in m/s)

Usage

.get_archive_wsp(syear)

Arguments

syear

shortyear in YY format

Value

data.frame


aire.zmvm documentation built on March 5, 2026, 5:07 p.m.