powered by
Data comes from Promedios de 24 horas de partículas suspendidas(PM10 Y PM2.5) and Promedios de 24 horas de Dióxido azufre
download_24hr_average(type, year, progress = interactive())
A data.frame with pollution data.
type of data to download.
SO2 - Sulfur Dioxide (parts per billion)
PS - Suspended solids
a numeric vector containing the years for which to download data (the earliest possible value is 1986 for SO2 and 1995 for PS)
whether to display a progress bar (TRUE or FALSE). By default it will only display in an interactive session.
if (FALSE) { head(download_24hr_average("PS", 2017)) }
Run the code above in your browser using DataLab