Learn R Programming

aire.zmvm (version 0.9.0)

download_meteorological: Download Meteorological Data Archives

Description

Download the files available at Meteorología

Usage

download_meteorological(year, progress = interactive())

Value

a data.frame with meterological information: "RH","TMP","WDR","WSP","PBa"

Arguments

year

a numeric vector containing the years for which to download data (the earliest possible value is 1986)

progress

whether to display a progress bar (TRUE or FALSE). By default it will only display in an interactive session.

Examples

Run this code
if (FALSE) {
head(download_meteorological(2017))
}

Run the code above in your browser using DataLab