powered by
Download the pollution files available at Contaminante
download_pollution(year, progress = interactive())
a data.frame with pollution information for the following pollutants "CO", "NO", "NO2", "NOX", "O3", "PM10", "SO2", "PM25", and "PMCO"
a numeric vector containing the years for which to download data (the earliest possible value is 2009)
whether to display a progress bar (TRUE or FALSE). By default it will only display in an interactive session.
if (FALSE) { head(download_pollution(2017)) }
Run the code above in your browser using DataLab