powered by
The data comes from Presión Atmosférica
download_pressure(year, progress = interactive())
A data.frame with atmospheric pressure data.
a numeric vector containing the years for which to download data (the earliest possible value is 2009)
whether to display a progress bar (TRUE or FALSE). By default it will only display in an interactive session.
if (FALSE) { head(download_pressure(2017)) }
Run the code above in your browser using DataLab