View source: R/get_latest_imeca.R
| get_latest_imeca | R Documentation |
Download the latest hourly values for the pollutants with the highest values for each station as measured in IMECAs
get_latest_imeca()
Note that in 2015 it was determined that the stations with codes ACO, AJU, INN, MON and MPA would no longer be taken into consideration when computing the pollution index because they didn't meet the objectives of monitoring air quality, and are no longer included in the index, even if they are still part of the SIMAT (Sistema de Monitoreo Atmosférico de la Ciudad de México). Thus, even if they are located inside a zone, they are not included in the pollution values for that zone.
A data.frame with pollution air quality, the hours are in the America/Mexico_City timezone
Other IMECA functions:
get_station_imeca(),
get_zone_imeca()
df <- get_latest_imeca()
head(df)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.