powered by
aire.zmvm
Tools for downloading data from each of the pollution, wind and temperature measuring stations in the Zona Metropolitana del Valle de México (greater Mexico City).
Maintainer: Diego Valle-Jones diego@diegovalle.net
See the README on GitHub
Useful links:
https://hoyodesmog.diegovalle.net/aire.zmvm/
https://github.com/diegovalle/aire.zmvm
Report bugs at https://github.com/diegovalle/aire.zmvm/issues