powered by
Download the files available at Meteorología
download_meteorological(year, progress = interactive())
a data.frame with meterological information: "RH","TMP","WDR","WSP","PBa"
a numeric vector containing the years for which to download data (the earliest possible value is 1986)
whether to display a progress bar (TRUE or FALSE). By default it will only display in an interactive session.
if (FALSE) { head(download_meteorological(2017)) }
Run the code above in your browser using DataLab